@@ -213,7 +213,7 @@ gis_driver_set_user_language (GisDriver *driver, const gchar *lang_id, gboolean
 
   if (update_locale)
     {
-      locale_t locale = newlocale (LC_MESSAGES_MASK, lang_id, (locale_t) 0);
+      locale_t locale = newlocale (LC_ALL_MASK, lang_id, (locale_t) 0);
       if (locale == (locale_t) 0)
         {
           g_warning ("Failed to create locale %s: %s", lang_id, g_strerror (errno));
@@ -722,7 +722,7 @@ update_screen_size (GisDriver *driver)
       gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
                                       GTK_POLICY_AUTOMATIC,
                                       GTK_POLICY_AUTOMATIC);
-      gtk_window_set_default_size (driver->main_window, -1, -1);
+      gtk_window_set_default_size (driver->main_window, 800, 600);
       gtk_window_set_resizable (driver->main_window, TRUE);
       gtk_window_maximize (driver->main_window);
       gtk_window_present (driver->main_window);
@@ -788,7 +788,9 @@ gis_driver_startup (GApplication *app)
 
   G_APPLICATION_CLASS (gis_driver_parent_class)->startup (app);
 
+#if !WEBKIT_CHECK_VERSION(2, 39, 5)
   webkit_web_context_set_sandbox_enabled (context, TRUE);
+#endif
 
   if (driver->mode == GIS_DRIVER_MODE_NEW_USER)
     connect_to_gdm (driver);
