@@ -19,8 +19,7 @@
  *     Jasper St. Pierre <jstpierre@mecheye.net>
  */
 
-#ifndef __GIS_ACCOUNT_PAGES_H__
-#define __GIS_ACCOUNT_PAGES_H__
+#pragma once
 
 #include <glib-object.h>
 
@@ -32,5 +31,3 @@ GisPage *gis_prepare_account_page (GisDriver *driver);
 
 G_END_DECLS
 
-#endif /* __GIS_ACCOUNT_PAGES_H__ */
-
